/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_window1 (void)
{
  GtkWidget *window1;
  GtkWidget *vbox1;
  GtkWidget *menubar1;
  GtkWidget *menuitem4;
  GtkWidget *menuitem4_menu;
  GtkWidget *ouvrir1;
  GtkWidget *separatormenuitem1;
  GtkWidget *quitter1;
  GtkWidget *configuration1;
  GtkWidget *configuration1_menu;
  GtkWidget *macro1;
  GtkWidget *training1;
  GtkWidget *menuitem7;
  GtkWidget *menuitem7_menu;
  GtkWidget *___propos1;
  GtkWidget *hbox1;
  GtkWidget *vbox2;
  GtkWidget *frame1;
  GtkObject *SpeedSpin_adj;
  GtkWidget *SpeedSpin;
  GtkWidget *label1;
  GtkWidget *frame2;
  GtkObject *SpaceSpin_adj;
  GtkWidget *SpaceSpin;
  GtkWidget *label2;
  GtkWidget *frame3;
  GtkObject *PitchSpin_adj;
  GtkWidget *PitchSpin;
  GtkWidget *label3;
  GtkWidget *frame4;
  GtkObject *ShapeSpin_adj;
  GtkWidget *ShapeSpin;
  GtkWidget *label22;
  GtkWidget *togglebutton1;
  GtkWidget *alignment2;
  GtkWidget *hbox5;
  GtkWidget *image2;
  GtkWidget *label23;
  GtkWidget *scrolledwindow1;
  GtkWidget *TxText;
  GtkWidget *vbuttonbox1;
  GtkWidget *macrobutton1;
  GtkWidget *macrobutton2;
  GtkWidget *macrobutton3;
  GtkWidget *macrobutton4;
  GtkWidget *macrobutton5;
  GtkWidget *macrobutton6;
  GtkWidget *macrobutton7;
  GtkWidget *macrobutton8;
  GtkWidget *Training_button;
  GtkWidget *alignment1;
  GtkWidget *hbox2;
  GtkWidget *image1;
  GtkWidget *label4;
  GtkWidget *statusbar1;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (window1), _("CWstation"));
  gtk_window_set_default_size (GTK_WINDOW (window1), 500, 300);

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window1), vbox1);

  menubar1 = gtk_menu_bar_new ();
  gtk_widget_show (menubar1);
  gtk_box_pack_start (GTK_BOX (vbox1), menubar1, FALSE, FALSE, 0);

  menuitem4 = gtk_menu_item_new_with_mnemonic (_("_Fichier"));
  gtk_widget_show (menuitem4);
  gtk_container_add (GTK_CONTAINER (menubar1), menuitem4);

  menuitem4_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem4), menuitem4_menu);

  ouvrir1 = gtk_image_menu_item_new_from_stock ("gtk-open", accel_group);
  gtk_widget_show (ouvrir1);
  gtk_container_add (GTK_CONTAINER (menuitem4_menu), ouvrir1);

  separatormenuitem1 = gtk_separator_menu_item_new ();
  gtk_widget_show (separatormenuitem1);
  gtk_container_add (GTK_CONTAINER (menuitem4_menu), separatormenuitem1);
  gtk_widget_set_sensitive (separatormenuitem1, FALSE);

  quitter1 = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
  gtk_widget_show (quitter1);
  gtk_container_add (GTK_CONTAINER (menuitem4_menu), quitter1);

  configuration1 = gtk_menu_item_new_with_mnemonic (_("Configuration"));
  gtk_widget_show (configuration1);
  gtk_container_add (GTK_CONTAINER (menubar1), configuration1);

  configuration1_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (configuration1), configuration1_menu);

  macro1 = gtk_menu_item_new_with_mnemonic (_("Macro"));
  gtk_widget_show (macro1);
  gtk_container_add (GTK_CONTAINER (configuration1_menu), macro1);

  training1 = gtk_menu_item_new_with_mnemonic (_("Training"));
  gtk_widget_show (training1);
  gtk_container_add (GTK_CONTAINER (configuration1_menu), training1);

  menuitem7 = gtk_image_menu_item_new_from_stock ("gtk-help", accel_group);
  gtk_widget_show (menuitem7);
  gtk_container_add (GTK_CONTAINER (menubar1), menuitem7);

  menuitem7_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem7), menuitem7_menu);

  ___propos1 = gtk_menu_item_new_with_mnemonic (_("\303\200 _propos"));
  gtk_widget_show (___propos1);
  gtk_container_add (GTK_CONTAINER (menuitem7_menu), ___propos1);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);

  frame1 = gtk_frame_new (NULL);
  gtk_widget_show (frame1);
  gtk_box_pack_start (GTK_BOX (vbox2), frame1, FALSE, FALSE, 0);

  SpeedSpin_adj = gtk_adjustment_new (12, 5, 30, 1, 5, 5);
  SpeedSpin = gtk_spin_button_new (GTK_ADJUSTMENT (SpeedSpin_adj), 12, 0);
  gtk_widget_show (SpeedSpin);
  gtk_container_add (GTK_CONTAINER (frame1), SpeedSpin);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (SpeedSpin), TRUE);
  gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (SpeedSpin), GTK_UPDATE_IF_VALID);

  label1 = gtk_label_new (_("Speed wpm"));
  gtk_widget_show (label1);
  gtk_frame_set_label_widget (GTK_FRAME (frame1), label1);

  frame2 = gtk_frame_new (NULL);
  gtk_widget_show (frame2);
  gtk_box_pack_start (GTK_BOX (vbox2), frame2, FALSE, FALSE, 0);

  SpaceSpin_adj = gtk_adjustment_new (100, 1, 300, 5, 50, 50);
  SpaceSpin = gtk_spin_button_new (GTK_ADJUSTMENT (SpaceSpin_adj), 1, 0);
  gtk_widget_show (SpaceSpin);
  gtk_container_add (GTK_CONTAINER (frame2), SpaceSpin);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (SpaceSpin), TRUE);
  gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (SpaceSpin), GTK_UPDATE_IF_VALID);

  label2 = gtk_label_new (_("Space %"));
  gtk_widget_show (label2);
  gtk_frame_set_label_widget (GTK_FRAME (frame2), label2);

  frame3 = gtk_frame_new (NULL);
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (vbox2), frame3, FALSE, FALSE, 0);

  PitchSpin_adj = gtk_adjustment_new (700, 100, 3000, 5, 100, 100);
  PitchSpin = gtk_spin_button_new (GTK_ADJUSTMENT (PitchSpin_adj), 1, 0);
  gtk_widget_show (PitchSpin);
  gtk_container_add (GTK_CONTAINER (frame3), PitchSpin);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (PitchSpin), TRUE);
  gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (PitchSpin), GTK_UPDATE_IF_VALID);

  label3 = gtk_label_new (_("Pitch Hz"));
  gtk_widget_show (label3);
  gtk_frame_set_label_widget (GTK_FRAME (frame3), label3);

  frame4 = gtk_frame_new (NULL);
  gtk_widget_show (frame4);
  gtk_box_pack_start (GTK_BOX (vbox2), frame4, FALSE, TRUE, 0);

  ShapeSpin_adj = gtk_adjustment_new (5, 0, 100, 5, 20, 20);
  ShapeSpin = gtk_spin_button_new (GTK_ADJUSTMENT (ShapeSpin_adj), 1, 0);
  gtk_widget_show (ShapeSpin);
  gtk_container_add (GTK_CONTAINER (frame4), ShapeSpin);
  gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (ShapeSpin), GTK_UPDATE_IF_VALID);

  label22 = gtk_label_new (_("Shape %"));
  gtk_widget_show (label22);
  gtk_frame_set_label_widget (GTK_FRAME (frame4), label22);

  togglebutton1 = gtk_toggle_button_new ();
  gtk_widget_show (togglebutton1);
  gtk_box_pack_end (GTK_BOX (vbox2), togglebutton1, FALSE, FALSE, 0);

  alignment2 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (togglebutton1), alignment2);

  hbox5 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox5);
  gtk_container_add (GTK_CONTAINER (alignment2), hbox5);

  image2 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox5), image2, FALSE, FALSE, 0);

  label23 = gtk_label_new_with_mnemonic (_("Tx"));
  gtk_widget_show (label23);
  gtk_box_pack_start (GTK_BOX (hbox5), label23, FALSE, FALSE, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_box_pack_start (GTK_BOX (hbox1), scrolledwindow1, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);

  TxText = gtk_text_view_new ();
  gtk_widget_show (TxText);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), TxText);
  gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW (TxText), FALSE);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (TxText), GTK_WRAP_WORD);

  vbuttonbox1 = gtk_vbutton_box_new ();
  gtk_widget_show (vbuttonbox1);
  gtk_box_pack_start (GTK_BOX (hbox1), vbuttonbox1, FALSE, FALSE, 0);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (vbuttonbox1), GTK_BUTTONBOX_START);

  macrobutton1 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton1);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton1);
  GTK_WIDGET_SET_FLAGS (macrobutton1, GTK_CAN_DEFAULT);

  macrobutton2 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton2);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton2);
  GTK_WIDGET_SET_FLAGS (macrobutton2, GTK_CAN_DEFAULT);

  macrobutton3 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton3);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton3);
  GTK_WIDGET_SET_FLAGS (macrobutton3, GTK_CAN_DEFAULT);

  macrobutton4 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton4);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton4);
  GTK_WIDGET_SET_FLAGS (macrobutton4, GTK_CAN_DEFAULT);

  macrobutton5 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton5);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton5);
  GTK_WIDGET_SET_FLAGS (macrobutton5, GTK_CAN_DEFAULT);

  macrobutton6 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton6);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton6);
  GTK_WIDGET_SET_FLAGS (macrobutton6, GTK_CAN_DEFAULT);

  macrobutton7 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton7);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton7);
  GTK_WIDGET_SET_FLAGS (macrobutton7, GTK_CAN_DEFAULT);

  macrobutton8 = gtk_button_new_with_mnemonic ("");
  gtk_widget_show (macrobutton8);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), macrobutton8);
  GTK_WIDGET_SET_FLAGS (macrobutton8, GTK_CAN_DEFAULT);

  Training_button = gtk_button_new ();
  gtk_widget_show (Training_button);
  gtk_container_add (GTK_CONTAINER (vbuttonbox1), Training_button);
  GTK_WIDGET_SET_FLAGS (Training_button, GTK_CAN_DEFAULT);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (Training_button), alignment1);

  hbox2 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox2);

  image1 = gtk_image_new_from_stock ("gtk-cdrom", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox2), image1, FALSE, FALSE, 0);

  label4 = gtk_label_new_with_mnemonic (_("Training"));
  gtk_widget_show (label4);
  gtk_box_pack_start (GTK_BOX (hbox2), label4, FALSE, FALSE, 0);

  statusbar1 = gtk_statusbar_new ();
  gtk_widget_show (statusbar1);
  gtk_box_pack_start (GTK_BOX (vbox1), statusbar1, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window1, "delete_event",
                    G_CALLBACK (gtk_main_quit),
                    NULL);
  g_signal_connect ((gpointer) ouvrir1, "activate",
                    G_CALLBACK (on_ouvrir1_activate),
                    NULL);
  g_signal_connect ((gpointer) quitter1, "activate",
                    G_CALLBACK (savequit),
                    NULL);
  g_signal_connect ((gpointer) configuration1, "activate",
                    G_CALLBACK (on_configuration1_activate),
                    NULL);
  g_signal_connect ((gpointer) macro1, "activate",
                    G_CALLBACK (on_macro1_activate),
                    NULL);
  g_signal_connect ((gpointer) training1, "activate",
                    G_CALLBACK (on_training1_activate),
                    NULL);
  g_signal_connect ((gpointer) ___propos1, "activate",
                    G_CALLBACK (on____propos1_activate),
                    NULL);
  g_signal_connect ((gpointer) SpeedSpin, "value_changed",
                    G_CALLBACK (on_speed_changed),
                    NULL);
  g_signal_connect ((gpointer) SpaceSpin, "value_changed",
                    G_CALLBACK (on_space_changed),
                    NULL);
  g_signal_connect ((gpointer) PitchSpin, "value_changed",
                    G_CALLBACK (on_pitch_changed),
                    NULL);
  g_signal_connect ((gpointer) ShapeSpin, "value_changed",
                    G_CALLBACK (on_shape_changed),
                    NULL);
  g_signal_connect ((gpointer) togglebutton1, "toggled",
                    G_CALLBACK (on_Tx_toggled),
                    NULL);
  g_signal_connect ((gpointer) macrobutton1, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton2, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton3, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton4, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton5, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton6, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton7, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) macrobutton8, "clicked",
                    G_CALLBACK (on_macro_clicked),
                    NULL);
  g_signal_connect ((gpointer) Training_button, "clicked",
                    G_CALLBACK (on_training_button_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window1, window1, "window1");
  GLADE_HOOKUP_OBJECT (window1, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window1, menubar1, "menubar1");
  GLADE_HOOKUP_OBJECT (window1, menuitem4, "menuitem4");
  GLADE_HOOKUP_OBJECT (window1, menuitem4_menu, "menuitem4_menu");
  GLADE_HOOKUP_OBJECT (window1, ouvrir1, "ouvrir1");
  GLADE_HOOKUP_OBJECT (window1, separatormenuitem1, "separatormenuitem1");
  GLADE_HOOKUP_OBJECT (window1, quitter1, "quitter1");
  GLADE_HOOKUP_OBJECT (window1, configuration1, "configuration1");
  GLADE_HOOKUP_OBJECT (window1, configuration1_menu, "configuration1_menu");
  GLADE_HOOKUP_OBJECT (window1, macro1, "macro1");
  GLADE_HOOKUP_OBJECT (window1, training1, "training1");
  GLADE_HOOKUP_OBJECT (window1, menuitem7, "menuitem7");
  GLADE_HOOKUP_OBJECT (window1, menuitem7_menu, "menuitem7_menu");
  GLADE_HOOKUP_OBJECT (window1, ___propos1, "___propos1");
  GLADE_HOOKUP_OBJECT (window1, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (window1, vbox2, "vbox2");
  GLADE_HOOKUP_OBJECT (window1, frame1, "frame1");
  GLADE_HOOKUP_OBJECT (window1, SpeedSpin, "SpeedSpin");
  GLADE_HOOKUP_OBJECT (window1, label1, "label1");
  GLADE_HOOKUP_OBJECT (window1, frame2, "frame2");
  GLADE_HOOKUP_OBJECT (window1, SpaceSpin, "SpaceSpin");
  GLADE_HOOKUP_OBJECT (window1, label2, "label2");
  GLADE_HOOKUP_OBJECT (window1, frame3, "frame3");
  GLADE_HOOKUP_OBJECT (window1, PitchSpin, "PitchSpin");
  GLADE_HOOKUP_OBJECT (window1, label3, "label3");
  GLADE_HOOKUP_OBJECT (window1, frame4, "frame4");
  GLADE_HOOKUP_OBJECT (window1, ShapeSpin, "ShapeSpin");
  GLADE_HOOKUP_OBJECT (window1, label22, "label22");
  GLADE_HOOKUP_OBJECT (window1, togglebutton1, "togglebutton1");
  GLADE_HOOKUP_OBJECT (window1, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (window1, hbox5, "hbox5");
  GLADE_HOOKUP_OBJECT (window1, image2, "image2");
  GLADE_HOOKUP_OBJECT (window1, label23, "label23");
  GLADE_HOOKUP_OBJECT (window1, scrolledwindow1, "scrolledwindow1");
  GLADE_HOOKUP_OBJECT (window1, TxText, "TxText");
  GLADE_HOOKUP_OBJECT (window1, vbuttonbox1, "vbuttonbox1");
  GLADE_HOOKUP_OBJECT (window1, macrobutton1, "macrobutton1");
  GLADE_HOOKUP_OBJECT (window1, macrobutton2, "macrobutton2");
  GLADE_HOOKUP_OBJECT (window1, macrobutton3, "macrobutton3");
  GLADE_HOOKUP_OBJECT (window1, macrobutton4, "macrobutton4");
  GLADE_HOOKUP_OBJECT (window1, macrobutton5, "macrobutton5");
  GLADE_HOOKUP_OBJECT (window1, macrobutton6, "macrobutton6");
  GLADE_HOOKUP_OBJECT (window1, macrobutton7, "macrobutton7");
  GLADE_HOOKUP_OBJECT (window1, macrobutton8, "macrobutton8");
  GLADE_HOOKUP_OBJECT (window1, Training_button, "Training_button");
  GLADE_HOOKUP_OBJECT (window1, alignment1, "alignment1");
  GLADE_HOOKUP_OBJECT (window1, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (window1, image1, "image1");
  GLADE_HOOKUP_OBJECT (window1, label4, "label4");
  GLADE_HOOKUP_OBJECT (window1, statusbar1, "statusbar1");

  gtk_window_add_accel_group (GTK_WINDOW (window1), accel_group);

  return window1;
}

GtkWidget*
create_MacroWin (void)
{
  GtkWidget *MacroWin;
  GtkWidget *dialog_vbox1;
  GtkWidget *table2;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *label9;
  GtkWidget *label10;
  GtkWidget *label11;
  GtkWidget *label12;
  GtkWidget *label14;
  GtkWidget *label15;
  GtkWidget *label13;
  GtkWidget *macrolabel1;
  GtkWidget *macrolabel2;
  GtkWidget *macrolabel3;
  GtkWidget *macrolabel4;
  GtkWidget *macrolabel5;
  GtkWidget *macrolabel6;
  GtkWidget *macrolabel7;
  GtkWidget *macrolabel8;
  GtkWidget *macrotxt2;
  GtkWidget *macrotxt3;
  GtkWidget *macrotxt4;
  GtkWidget *macrotxt5;
  GtkWidget *macrotxt6;
  GtkWidget *macrotxt7;
  GtkWidget *macrotxt8;
  GtkWidget *macrotxt1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton_mac;
  GtkWidget *okbutton_mac;

  MacroWin = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (MacroWin), _("Macro"));

  dialog_vbox1 = GTK_DIALOG (MacroWin)->vbox;
  gtk_widget_show (dialog_vbox1);

  table2 = gtk_table_new (9, 3, FALSE);
  gtk_widget_show (table2);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), table2, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table2), 10);
  gtk_table_set_row_spacings (GTK_TABLE (table2), 5);
  gtk_table_set_col_spacings (GTK_TABLE (table2), 10);

  label6 = gtk_label_new (_("1 :"));
  gtk_widget_show (label6);
  gtk_table_attach (GTK_TABLE (table2), label6, 0, 1, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label6), 0, 0.5);

  label7 = gtk_label_new (_("2 :"));
  gtk_widget_show (label7);
  gtk_table_attach (GTK_TABLE (table2), label7, 0, 1, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label7), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label7), 0, 0.5);

  label8 = gtk_label_new (_("3 :"));
  gtk_widget_show (label8);
  gtk_table_attach (GTK_TABLE (table2), label8, 0, 1, 3, 4,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label8), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);

  label9 = gtk_label_new (_("4 :"));
  gtk_widget_show (label9);
  gtk_table_attach (GTK_TABLE (table2), label9, 0, 1, 4, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label9), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label9), 0, 0.5);

  label10 = gtk_label_new (_("5 :"));
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table2), label10, 0, 1, 5, 6,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label10), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label10), 0, 0.5);

  label11 = gtk_label_new (_("6 :"));
  gtk_widget_show (label11);
  gtk_table_attach (GTK_TABLE (table2), label11, 0, 1, 6, 7,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label11), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label11), 0, 0.5);

  label12 = gtk_label_new (_("7 :"));
  gtk_widget_show (label12);
  gtk_table_attach (GTK_TABLE (table2), label12, 0, 1, 7, 8,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label12), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label12), 0, 0.5);

  label14 = gtk_label_new (_("<big>Macro</big>\n"));
  gtk_widget_show (label14);
  gtk_table_attach (GTK_TABLE (table2), label14, 2, 3, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_use_markup (GTK_LABEL (label14), TRUE);
  gtk_label_set_justify (GTK_LABEL (label14), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0);

  label15 = gtk_label_new (_("8 :"));
  gtk_widget_show (label15);
  gtk_table_attach (GTK_TABLE (table2), label15, 0, 1, 8, 9,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label15), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label15), 0, 0.5);

  label13 = gtk_label_new (_("<big>Button</big>\n"));
  gtk_widget_show (label13);
  gtk_table_attach (GTK_TABLE (table2), label13, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_use_markup (GTK_LABEL (label13), TRUE);
  gtk_label_set_justify (GTK_LABEL (label13), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label13), 0, 0);

  macrolabel1 = gtk_entry_new ();
  gtk_widget_show (macrolabel1);
  gtk_table_attach (GTK_TABLE (table2), macrolabel1, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel1), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel1), 10);

  macrolabel2 = gtk_entry_new ();
  gtk_widget_show (macrolabel2);
  gtk_table_attach (GTK_TABLE (table2), macrolabel2, 1, 2, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel2), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel2), 10);

  macrolabel3 = gtk_entry_new ();
  gtk_widget_show (macrolabel3);
  gtk_table_attach (GTK_TABLE (table2), macrolabel3, 1, 2, 3, 4,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel3), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel3), 10);

  macrolabel4 = gtk_entry_new ();
  gtk_widget_show (macrolabel4);
  gtk_table_attach (GTK_TABLE (table2), macrolabel4, 1, 2, 4, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel4), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel4), 10);

  macrolabel5 = gtk_entry_new ();
  gtk_widget_show (macrolabel5);
  gtk_table_attach (GTK_TABLE (table2), macrolabel5, 1, 2, 5, 6,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel5), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel5), 10);

  macrolabel6 = gtk_entry_new ();
  gtk_widget_show (macrolabel6);
  gtk_table_attach (GTK_TABLE (table2), macrolabel6, 1, 2, 6, 7,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel6), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel6), 10);

  macrolabel7 = gtk_entry_new ();
  gtk_widget_show (macrolabel7);
  gtk_table_attach (GTK_TABLE (table2), macrolabel7, 1, 2, 7, 8,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel7), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel7), 10);

  macrolabel8 = gtk_entry_new ();
  gtk_widget_show (macrolabel8);
  gtk_table_attach (GTK_TABLE (table2), macrolabel8, 1, 2, 8, 9,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_max_length (GTK_ENTRY (macrolabel8), 10);
  gtk_entry_set_width_chars (GTK_ENTRY (macrolabel8), 10);

  macrotxt2 = gtk_entry_new ();
  gtk_widget_show (macrotxt2);
  gtk_table_attach (GTK_TABLE (table2), macrotxt2, 2, 3, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt2), 60);

  macrotxt3 = gtk_entry_new ();
  gtk_widget_show (macrotxt3);
  gtk_table_attach (GTK_TABLE (table2), macrotxt3, 2, 3, 3, 4,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt3), 60);

  macrotxt4 = gtk_entry_new ();
  gtk_widget_show (macrotxt4);
  gtk_table_attach (GTK_TABLE (table2), macrotxt4, 2, 3, 4, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt4), 60);

  macrotxt5 = gtk_entry_new ();
  gtk_widget_show (macrotxt5);
  gtk_table_attach (GTK_TABLE (table2), macrotxt5, 2, 3, 5, 6,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt5), 60);

  macrotxt6 = gtk_entry_new ();
  gtk_widget_show (macrotxt6);
  gtk_table_attach (GTK_TABLE (table2), macrotxt6, 2, 3, 6, 7,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt6), 60);

  macrotxt7 = gtk_entry_new ();
  gtk_widget_show (macrotxt7);
  gtk_table_attach (GTK_TABLE (table2), macrotxt7, 2, 3, 7, 8,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt7), 60);

  macrotxt8 = gtk_entry_new ();
  gtk_widget_show (macrotxt8);
  gtk_table_attach (GTK_TABLE (table2), macrotxt8, 2, 3, 8, 9,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt8), 60);

  macrotxt1 = gtk_entry_new ();
  gtk_widget_show (macrotxt1);
  gtk_table_attach (GTK_TABLE (table2), macrotxt1, 2, 3, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (macrotxt1), 60);

  dialog_action_area1 = GTK_DIALOG (MacroWin)->action_area;
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  cancelbutton_mac = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton_mac);
  gtk_dialog_add_action_widget (GTK_DIALOG (MacroWin), cancelbutton_mac, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton_mac, GTK_CAN_DEFAULT);

  okbutton_mac = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton_mac);
  gtk_dialog_add_action_widget (GTK_DIALOG (MacroWin), okbutton_mac, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton_mac, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) cancelbutton_mac, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (MacroWin));
  g_signal_connect ((gpointer) okbutton_mac, "clicked",
                    G_CALLBACK (on_okbutton_mac_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (MacroWin, MacroWin, "MacroWin");
  GLADE_HOOKUP_OBJECT_NO_REF (MacroWin, dialog_vbox1, "dialog_vbox1");
  GLADE_HOOKUP_OBJECT (MacroWin, table2, "table2");
  GLADE_HOOKUP_OBJECT (MacroWin, label6, "label6");
  GLADE_HOOKUP_OBJECT (MacroWin, label7, "label7");
  GLADE_HOOKUP_OBJECT (MacroWin, label8, "label8");
  GLADE_HOOKUP_OBJECT (MacroWin, label9, "label9");
  GLADE_HOOKUP_OBJECT (MacroWin, label10, "label10");
  GLADE_HOOKUP_OBJECT (MacroWin, label11, "label11");
  GLADE_HOOKUP_OBJECT (MacroWin, label12, "label12");
  GLADE_HOOKUP_OBJECT (MacroWin, label14, "label14");
  GLADE_HOOKUP_OBJECT (MacroWin, label15, "label15");
  GLADE_HOOKUP_OBJECT (MacroWin, label13, "label13");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel1, "macrolabel1");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel2, "macrolabel2");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel3, "macrolabel3");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel4, "macrolabel4");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel5, "macrolabel5");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel6, "macrolabel6");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel7, "macrolabel7");
  GLADE_HOOKUP_OBJECT (MacroWin, macrolabel8, "macrolabel8");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt2, "macrotxt2");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt3, "macrotxt3");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt4, "macrotxt4");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt5, "macrotxt5");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt6, "macrotxt6");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt7, "macrotxt7");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt8, "macrotxt8");
  GLADE_HOOKUP_OBJECT (MacroWin, macrotxt1, "macrotxt1");
  GLADE_HOOKUP_OBJECT_NO_REF (MacroWin, dialog_action_area1, "dialog_action_area1");
  GLADE_HOOKUP_OBJECT (MacroWin, cancelbutton_mac, "cancelbutton_mac");
  GLADE_HOOKUP_OBJECT (MacroWin, okbutton_mac, "okbutton_mac");

  return MacroWin;
}

GtkWidget*
create_Training (void)
{
  GtkWidget *Training;
  GtkWidget *dialog_vbox2;
  GtkWidget *hbox3;
  GtkWidget *label18;
  GtkWidget *TrainingAlphabet;
  GtkWidget *hbox4;
  GtkWidget *label19;
  GtkObject *trminSpin_adj;
  GtkWidget *trminSpin;
  GtkWidget *label20;
  GtkObject *trmaxSpin_adj;
  GtkWidget *trmaxSpin;
  GtkWidget *label21;
  GtkObject *trlenSpin_adj;
  GtkWidget *trlenSpin;
  GtkWidget *hseparator1;
  GtkWidget *dialog_action_area2;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;

  Training = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (Training), _("Training"));

  dialog_vbox2 = GTK_DIALOG (Training)->vbox;
  gtk_widget_show (dialog_vbox2);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), hbox3, TRUE, TRUE, 0);

  label18 = gtk_label_new (_("Characters : "));
  gtk_widget_show (label18);
  gtk_box_pack_start (GTK_BOX (hbox3), label18, FALSE, FALSE, 0);

  TrainingAlphabet = gtk_combo_box_entry_new_text ();
  gtk_widget_show (TrainingAlphabet);
  gtk_box_pack_start (GTK_BOX (hbox3), TrainingAlphabet, TRUE, TRUE, 0);
  gtk_combo_box_append_text (GTK_COMBO_BOX (TrainingAlphabet), _("KMRSUAPTL0WI.NJEFOY,VG5/Q9ZH38B?427C1D6X"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (TrainingAlphabet), _("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789.,/"));

  hbox4 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox4);
  gtk_box_pack_end (GTK_BOX (dialog_vbox2), hbox4, FALSE, FALSE, 0);

  label19 = gtk_label_new (_("Group Min: "));
  gtk_widget_show (label19);
  gtk_box_pack_start (GTK_BOX (hbox4), label19, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label19), 5, 5);

  trminSpin_adj = gtk_adjustment_new (5, 1, 25, 1, 10, 10);
  trminSpin = gtk_spin_button_new (GTK_ADJUSTMENT (trminSpin_adj), 1, 0);
  gtk_widget_show (trminSpin);
  gtk_box_pack_start (GTK_BOX (hbox4), trminSpin, FALSE, FALSE, 0);

  label20 = gtk_label_new (_("Max : "));
  gtk_widget_show (label20);
  gtk_box_pack_start (GTK_BOX (hbox4), label20, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label20), 5, 5);

  trmaxSpin_adj = gtk_adjustment_new (5, 1, 25, 1, 10, 10);
  trmaxSpin = gtk_spin_button_new (GTK_ADJUSTMENT (trmaxSpin_adj), 1, 0);
  gtk_widget_show (trmaxSpin);
  gtk_box_pack_start (GTK_BOX (hbox4), trmaxSpin, FALSE, FALSE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (trmaxSpin), TRUE);

  label21 = gtk_label_new (_(" Text Length : "));
  gtk_widget_show (label21);
  gtk_box_pack_start (GTK_BOX (hbox4), label21, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label21), 5, 5);

  trlenSpin_adj = gtk_adjustment_new (100, 1, 1000, 1, 10, 10);
  trlenSpin = gtk_spin_button_new (GTK_ADJUSTMENT (trlenSpin_adj), 1, 0);
  gtk_widget_show (trlenSpin);
  gtk_box_pack_start (GTK_BOX (hbox4), trlenSpin, FALSE, FALSE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (trlenSpin), TRUE);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), hseparator1, TRUE, TRUE, 0);

  dialog_action_area2 = GTK_DIALOG (Training)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  cancelbutton1 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (Training), cancelbutton1, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton1, GTK_CAN_DEFAULT);

  okbutton1 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (Training), okbutton1, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton1, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) cancelbutton1, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (Training));
  g_signal_connect ((gpointer) okbutton1, "clicked",
                    G_CALLBACK (on_oktraining_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (Training, Training, "Training");
  GLADE_HOOKUP_OBJECT_NO_REF (Training, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (Training, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (Training, label18, "label18");
  GLADE_HOOKUP_OBJECT (Training, TrainingAlphabet, "TrainingAlphabet");
  GLADE_HOOKUP_OBJECT (Training, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (Training, label19, "label19");
  GLADE_HOOKUP_OBJECT (Training, trminSpin, "trminSpin");
  GLADE_HOOKUP_OBJECT (Training, label20, "label20");
  GLADE_HOOKUP_OBJECT (Training, trmaxSpin, "trmaxSpin");
  GLADE_HOOKUP_OBJECT (Training, label21, "label21");
  GLADE_HOOKUP_OBJECT (Training, trlenSpin, "trlenSpin");
  GLADE_HOOKUP_OBJECT (Training, hseparator1, "hseparator1");
  GLADE_HOOKUP_OBJECT_NO_REF (Training, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (Training, cancelbutton1, "cancelbutton1");
  GLADE_HOOKUP_OBJECT (Training, okbutton1, "okbutton1");

  return Training;
}

GtkWidget*
create_openfilechooser (void)
{
  GtkWidget *openfilechooser;
  GtkWidget *dialog_vbox3;
  GtkWidget *dialog_action_area3;
  GtkWidget *button9;
  GtkWidget *button10;

  openfilechooser = gtk_file_chooser_dialog_new (_("Open Text"), NULL, GTK_FILE_CHOOSER_ACTION_OPEN, NULL);
  gtk_window_set_resizable (GTK_WINDOW (openfilechooser), FALSE);

  dialog_vbox3 = GTK_DIALOG (openfilechooser)->vbox;
  gtk_widget_show (dialog_vbox3);

  dialog_action_area3 = GTK_DIALOG (openfilechooser)->action_area;
  gtk_widget_show (dialog_action_area3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area3), GTK_BUTTONBOX_END);

  button9 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (button9);
  gtk_dialog_add_action_widget (GTK_DIALOG (openfilechooser), button9, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (button9, GTK_CAN_DEFAULT);

  button10 = gtk_button_new_from_stock ("gtk-open");
  gtk_widget_show (button10);
  gtk_dialog_add_action_widget (GTK_DIALOG (openfilechooser), button10, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (button10, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) button9, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (openfilechooser));
  g_signal_connect ((gpointer) button10, "clicked",
                    G_CALLBACK (on_openfile_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (openfilechooser, openfilechooser, "openfilechooser");
  GLADE_HOOKUP_OBJECT_NO_REF (openfilechooser, dialog_vbox3, "dialog_vbox3");
  GLADE_HOOKUP_OBJECT_NO_REF (openfilechooser, dialog_action_area3, "dialog_action_area3");
  GLADE_HOOKUP_OBJECT (openfilechooser, button9, "button9");
  GLADE_HOOKUP_OBJECT (openfilechooser, button10, "button10");

  gtk_widget_grab_default (button10);
  return openfilechooser;
}

GtkWidget*
create_apropos (void)
{
  GtkWidget *apropos;
  GtkWidget *dialog_vbox4;
  GtkWidget *label24;
  GtkWidget *dialog_action_area4;
  GtkWidget *closebutton1;

  apropos = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (apropos), _("A propos"));
  gtk_window_set_modal (GTK_WINDOW (apropos), TRUE);
  gtk_window_set_resizable (GTK_WINDOW (apropos), FALSE);

  dialog_vbox4 = GTK_DIALOG (apropos)->vbox;
  gtk_widget_show (dialog_vbox4);

  label24 = gtk_label_new (_("<big>GCW 0.1\n\302\251 Thierry Leconte 2004\nemail: f4dwv@radioamateur.org\n</big>"));
  gtk_widget_show (label24);
  gtk_box_pack_start (GTK_BOX (dialog_vbox4), label24, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label24), TRUE);
  gtk_label_set_justify (GTK_LABEL (label24), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label24), 10, 15);

  dialog_action_area4 = GTK_DIALOG (apropos)->action_area;
  gtk_widget_show (dialog_action_area4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area4), GTK_BUTTONBOX_END);

  closebutton1 = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (closebutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (apropos), closebutton1, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (closebutton1, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) closebutton1, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (apropos));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (apropos, apropos, "apropos");
  GLADE_HOOKUP_OBJECT_NO_REF (apropos, dialog_vbox4, "dialog_vbox4");
  GLADE_HOOKUP_OBJECT (apropos, label24, "label24");
  GLADE_HOOKUP_OBJECT_NO_REF (apropos, dialog_action_area4, "dialog_action_area4");
  GLADE_HOOKUP_OBJECT (apropos, closebutton1, "closebutton1");

  return apropos;
}

