/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

GtkWidget* create_window1 (void);
GtkWidget* create_MacroWin (void);
GtkWidget* create_Training (void);
GtkWidget* create_openfilechooser (void);
GtkWidget* create_apropos (void);
