#include <gtk/gtk.h>


void
on_nouveau1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_ouvrir1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enregistrer1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_enregistrer_sous1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_quitter1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_couper1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_copier1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_coller1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_supprimer1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on____propos1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_textview1_insert_at_cursor          (GtkTextView     *textview,
                                        gchar           *string,
                                        gpointer         user_data);

void
on_SpeedSpin_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_SpaceSpin_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_PicthSpin_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_txtext_insert_at_cursor             (GtkTextView     *textview,
                                        gchar           *string,
                                        gpointer         user_data);

void
on_configuration1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macro1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_training1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cancelbutton_mac_activate           (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_mac_activate               (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancelbutton_mac_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_mac_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_cwdit_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_cxdit_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_canceltraining_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_oktraining_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_deletewin_activate                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_training_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);


void
on_Tx_toggled                          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_deletefilechooser_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_openfile_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_macro_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_speed_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_space_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_pitch_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_shape_changed                       (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
savequit                               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
